/**
*	Author:	Elizabeth Labelle
*	Project:	Boids Simulation
*	Date:		December 2010
*
*	Description:	The World class is used to define world boundaries so the Boids and
*					AttackBoids in the scene do not move to far from the camera or fly through
*					the ground or mountain geometry.
*					It also checks if there are no more Boids in the scene and restarts if there aren't.
*/
using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class World : MonoBehaviour 
{
	public float xMin = -180.0f;
	public float xMax = 180.0f;
	public float yMin = 20.0f;
	public float yMax = 180.0f;
	public float zMin = -180.0f;
	public float zMax = 180.0f;
	
	void Start()
	{
		if(tag == "" || tag == null)
			tag = "WorldData";
	}
	
	/**
	*	Checks if any Boids remain in the scene. If there are none, the method restarts the program.
	*/
	public void checkRestart()
	{
		GameObject[] flocks = GameObject.FindGameObjectsWithTag("BoidManager");
		bool boidsLeft = false;
		
		foreach(GameObject flock in flocks)
		{
			BoidManager bmanager = flock.GetComponent<BoidManager>();
			if(bmanager.boidList.Count > 0)
				boidsLeft = true;
		}
		
		if(!boidsLeft)
			Application.LoadLevel(Application.loadedLevel);
	}
}
